@@ -30,6 +30,7 @@ import time
 
 import gtk
 import gobject
+import dbus
 
 # At the moment, we don't have gettext support, so
 # make a dummy "_" function to passthrough the string
@@ -387,6 +388,14 @@ class GTK_Main(object):
             interface.headset_device.connect_to_signal(
                 'Condition', self.handle_headset_button )
 
+            # Monitor connection state of BT headset
+            system_bus = dbus.SystemBus()
+            def handler_func(device_path):
+                if device_path == '/org/freedesktop/Hal/devices/computer_logicaldev_input_1' and settings.play_on_headset and not player.playing:
+                    player.play()
+            system_bus.add_signal_receiver(handler_func, 'DeviceAdded', 'org.freedesktop.Hal.Manager', None, '/org/freedesktop/Hal/Manager')
+            # End Monitor connection state of BT headset
+
         player.register( 'stopped', self.on_player_stopped )
         player.register( 'playing', self.on_player_playing )
         player.register( 'paused', self.on_player_paused )
@@ -685,6 +694,13 @@ class GTK_Main(object):
         menu_lock_progress.set_active(self.lock_progress)
         menu.append(menu_lock_progress)
 
+	menu_play_headset = hildon.CheckButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+	menu_play_headset.set_label('Auto-play on headset')
+	menu_play_headset.set_alignment(.5, .5)
+        menu_play_headset.connect('toggled', lambda w: setattr(settings, 'play_on_headset', w.get_active()))
+        menu_play_headset.set_active(settings.play_on_headset)
+        menu.append(menu_play_headset)
+
 	menu_about = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
 	menu_about.set_text(_('About Panucci'), '')
         menu_about.connect('clicked', self.show_about, self.main_window)
